# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Button(Component):
    """A Button component.
Carbon Button

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional):
    Specify the content of your Button.

- id (string; required):
    The id of the button.

- className (string; optional):
    Specify an optional className to be added to your Button.

- dangerDescription (string; optional):
    Specify the message read by screen readers for the danger button
    variant.

- disabled (boolean; optional):
    Specify whether the Button should be disabled, or not.

- href (string; optional):
    Optionally specify an href for your Button to become an `<a>`
    element.

- isSelected (boolean; optional):
    Specify whether the Button is currently selected.

- kind (a value equal to: 'primary', 'secondary', 'danger', 'ghost', 'danger--primary', 'danger--ghost', 'danger--tertiary', 'tertiary'; required):
    Specify the kind of Button you want to create.

- n_clicks (number; default 0):
    Number of times this button has been clicked.

- role (string; optional):
    Optional prop to specify the role of the Button.

- size (a value equal to: 'default', 'field', 'small', 'sm', 'lg', 'xl'; optional):
    Specify the size of the button, from a list of available sizes.
    For `default` buttons, this prop can remain unspecified.

- style (dict; optional):
    jsx Style.

- tooltipAlignment (a value equal to: 'start', 'center', 'end'; optional):
    Specify the alignment of the tooltip to the icon-only button. Can
    be one of: start, center, or end.

- tooltipPosition (a value equal to: 'top', 'right', 'bottom', 'left'; optional):
    Specify the direction of the tooltip for icon-only buttons. Can be
    either top, right, bottom, or left.

- type (a value equal to: 'button', 'reset', 'submit'; optional):
    Optional prop to specify the type of the Button."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'Button'
    @_explicitize_args
    def __init__(self, children=None, id=Component.REQUIRED, style=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, dangerDescription=Component.UNDEFINED, href=Component.UNDEFINED, isSelected=Component.UNDEFINED, kind=Component.REQUIRED, role=Component.UNDEFINED, size=Component.UNDEFINED, tooltipAlignment=Component.UNDEFINED, tooltipPosition=Component.UNDEFINED, type=Component.UNDEFINED, n_clicks=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'dangerDescription', 'disabled', 'href', 'isSelected', 'kind', 'n_clicks', 'role', 'size', 'style', 'tooltipAlignment', 'tooltipPosition', 'type']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'dangerDescription', 'disabled', 'href', 'isSelected', 'kind', 'n_clicks', 'role', 'size', 'style', 'tooltipAlignment', 'tooltipPosition', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id', 'kind']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Button, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Card(Component):
    """A Card component.
Card to display content

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional):
    The children of the element.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- action_click (string; optional):
    The action click value.

- actions (list of dicts; optional):
    Actions available on the side menu, button clicks will be
    outputted to the actionPropName prop of this card.

    `actions` is a list of dicts with keys:

    - actionPropName (string; optional)

    - displayName (string; optional)

- className (string; default ''):
    The class of the element.

- info (string; optional):
    Additional information about the content of this card.

- style (dict; optional):
    The inline styles.

- title (string; optional):
    Title of the card."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'Card'
    @_explicitize_args
    def __init__(self, children=None, style=Component.UNDEFINED, id=Component.UNDEFINED, className=Component.UNDEFINED, title=Component.UNDEFINED, info=Component.UNDEFINED, actions=Component.UNDEFINED, action_click=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'action_click', 'actions', 'className', 'info', 'style', 'title']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'action_click', 'actions', 'className', 'info', 'style', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Card, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DatePickerRange(Component):
    """A DatePickerRange component.
DatePickerRange, the id of the DateInputs will be id + '-start' and id + '-end'

Keyword arguments:

- id (string; required):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- dateFormat (string; optional):
    The date format.

- endLabel (string; required):
    End input label.

- light (boolean; optional):
    True to use the light version.

- locale (string; optional):
    The language locale used to format the days of the week, months,
    and numbers. The full list of supported locales can be found here
    https://github.com/flatpickr/flatpickr/tree/master/src/l10n.

- maxDate (string; optional):
    The maximum date that a user can pick to.

- minDate (string; optional):
    The minimum date that a user can start picking from.

- placeholder (string; required):
    placeholder.

- short (boolean; optional):
    True to use the short version.

- startLabel (string; required):
    Start input label.

- style (dict; optional):
    jsx Style.

- value (string | list of strings; optional):
    The value of the date value provided to flatpickr."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'DatePickerRange'
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, dateFormat=Component.UNDEFINED, light=Component.UNDEFINED, locale=Component.UNDEFINED, maxDate=Component.UNDEFINED, minDate=Component.UNDEFINED, short=Component.UNDEFINED, value=Component.UNDEFINED, startLabel=Component.REQUIRED, endLabel=Component.REQUIRED, placeholder=Component.REQUIRED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'dateFormat', 'endLabel', 'light', 'locale', 'maxDate', 'minDate', 'placeholder', 'short', 'startLabel', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'dateFormat', 'endLabel', 'light', 'locale', 'maxDate', 'minDate', 'placeholder', 'short', 'startLabel', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id', 'endLabel', 'placeholder', 'startLabel']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DatePickerRange, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Modal(Component):
    """A Modal component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    Provide the contents of your Modal.

- id (string; optional):
    Specify the DOM element ID of the top-level node.

- alert (boolean; optional):
    Specify whether the Modal is displaying an alert, error or warning
    Should go hand in hand with the danger prop.

- className (string; optional):
    Specify an optional className to be applied to the modal root
    node.

- closeButtonLabel (string; optional):
    Specify an label for the close button of the modal; defaults to
    close.

- close_n_clicks (number; default 0):
    Number of times close button has been clicked.

- danger (boolean; optional):
    Specify whether the Modal is for dangerous actions.

- hasScrollingContent (boolean; optional):
    Specify whether the modal contains scrolling content.

- modalAriaLabel (string; optional):
    Specify a label to be read by screen readers on the modal root
    node.

- modalHeading (a list of or a singular dash component, string or number; optional):
    Specify the content of the modal header title.

- modalLabel (a list of or a singular dash component, string or number; optional):
    Specify the content of the modal header label.

- open (boolean; optional):
    Specify whether the Modal is currently open.

- passiveModal (boolean; optional):
    Specify whether the modal should be button-less.

- preventCloseOnClickOutside (boolean; optional):
    Prevent closing on click outside of modal.

- primaryButtonDisabled (boolean; optional):
    Specify whether the Button should be disabled, or not.

- primaryButtonText (a list of or a singular dash component, string or number; optional):
    Specify the text for the primary button.

- secondaryButtonText (a list of or a singular dash component, string or number; optional):
    Specify the text for the secondary button.

- secondary_submit_n_clicks (number; default 0):
    Number of times secondary submit button has been clicked.

- selectorPrimaryFocus (string; optional):
    Specify a CSS selector that matches the DOM element that should be
    focused when the Modal opens.

- selectorsFloatingMenus (list of strings; optional):
    Specify CSS selectors that match DOM elements working as floating
    menus. Focusing on those elements won't trigger \"focus-wrap\"
    behavior.

- shouldSubmitOnEnter (boolean; optional):
    Specify if Enter key should be used as \"submit\" action.

- size (a value equal to: 'xs', 'sm', 'md', 'lg'; optional):
    Specify the size variant.

- submit_n_clicks (number; default 0):
    Number of times submit button has been clicked."""
    _children_props = ['modalHeading', 'modalLabel', 'primaryButtonText', 'secondaryButtonText']
    _base_nodes = ['modalHeading', 'modalLabel', 'primaryButtonText', 'secondaryButtonText', 'children']
    _namespace = 'dash_carbon_components'
    _type = 'Modal'
    @_explicitize_args
    def __init__(self, children=None, alert=Component.UNDEFINED, className=Component.UNDEFINED, closeButtonLabel=Component.UNDEFINED, danger=Component.UNDEFINED, hasScrollingContent=Component.UNDEFINED, id=Component.UNDEFINED, modalAriaLabel=Component.UNDEFINED, modalHeading=Component.UNDEFINED, modalLabel=Component.UNDEFINED, open=Component.UNDEFINED, passiveModal=Component.UNDEFINED, preventCloseOnClickOutside=Component.UNDEFINED, primaryButtonDisabled=Component.UNDEFINED, primaryButtonText=Component.UNDEFINED, secondaryButtonText=Component.UNDEFINED, selectorPrimaryFocus=Component.UNDEFINED, selectorsFloatingMenus=Component.UNDEFINED, shouldSubmitOnEnter=Component.UNDEFINED, size=Component.UNDEFINED, close_n_clicks=Component.UNDEFINED, submit_n_clicks=Component.UNDEFINED, secondary_submit_n_clicks=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'alert', 'className', 'closeButtonLabel', 'close_n_clicks', 'danger', 'hasScrollingContent', 'modalAriaLabel', 'modalHeading', 'modalLabel', 'open', 'passiveModal', 'preventCloseOnClickOutside', 'primaryButtonDisabled', 'primaryButtonText', 'secondaryButtonText', 'secondary_submit_n_clicks', 'selectorPrimaryFocus', 'selectorsFloatingMenus', 'shouldSubmitOnEnter', 'size', 'submit_n_clicks']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'alert', 'className', 'closeButtonLabel', 'close_n_clicks', 'danger', 'hasScrollingContent', 'modalAriaLabel', 'modalHeading', 'modalLabel', 'open', 'passiveModal', 'preventCloseOnClickOutside', 'primaryButtonDisabled', 'primaryButtonText', 'secondaryButtonText', 'secondary_submit_n_clicks', 'selectorPrimaryFocus', 'selectorsFloatingMenus', 'shouldSubmitOnEnter', 'size', 'submit_n_clicks']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Modal, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tab(Component):
    """A Tab component.
Tab component

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional):
    Tab content.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- className (string; optional):
    Specify an optional className to be added to your Tab.

- disabled (boolean; optional):
    Whether your Tab is disabled.

- hidden (boolean; optional):
    Whether your Tab is disabled.

- label (string; required):
    Provide the contents of your Tab.

- role (string; optional):
    Provide an accessibility role for your Tab.

- style (dict; optional):
    jsx Style.

- value (string; optional):
    Value of the tab."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'Tab'
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, className=Component.UNDEFINED, disabled=Component.UNDEFINED, hidden=Component.UNDEFINED, label=Component.REQUIRED, role=Component.UNDEFINED, value=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'disabled', 'hidden', 'label', 'role', 'style', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'disabled', 'hidden', 'label', 'role', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tab, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tabs(Component):
    """A Tabs component.
Tabs

Keyword arguments:

- children (list of a list of or a singular dash component, string or numbers | a list of or a singular dash component, string or number; optional):
    Pass in a collection of <Tab> children to be rendered depending on
    the currently selected tab.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- ariaLabel (string; optional):
    Specify the text to be read by screen-readers when visiting the
    <Tabs> component.

- className (string; optional):
    Provide a className that is applied to the root <nav> component
    for the <Tabs>.

- headerOffsets (list of strings; optional):
    Number of columns of left offset the header will have.

- headerSizes (list of strings; optional):
    Number of columns the header will have.

- hidden (boolean; optional):
    Specify whether the Tab content is hidden.

- iconDescription (string; default 'show menu options'):
    Provide a description that is read out when a user visits the
    caret icon for the dropdown menu of items.

- role (string; default 'navigation'):
    By default, this value is \"navigation\". You can also provide an
    alternate role if it makes sense from the accessibility-side.

- selected (number; optional):
    Optionally provide an index for the currently selected <Tab>.

- style (dict; optional):
    Specify the inline style.

- tabContentClassName (string; optional):
    Provide a className that is applied to the <TabContent>
    components.

- triggerHref (string; default '#'):
    Provide a string that represents the `href` for the triggered
    <Tab>.

- value (string; optional):
    Value of the selected tab."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'Tabs'
    @_explicitize_args
    def __init__(self, children=None, ariaLabel=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, hidden=Component.UNDEFINED, role=Component.UNDEFINED, onClick=Component.UNDEFINED, onKeyDown=Component.UNDEFINED, triggerHref=Component.UNDEFINED, selected=Component.UNDEFINED, iconDescription=Component.UNDEFINED, tabContentClassName=Component.UNDEFINED, id=Component.UNDEFINED, headerOffsets=Component.UNDEFINED, headerSizes=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'ariaLabel', 'className', 'headerOffsets', 'headerSizes', 'hidden', 'iconDescription', 'role', 'selected', 'style', 'tabContentClassName', 'triggerHref', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'ariaLabel', 'className', 'headerOffsets', 'headerSizes', 'hidden', 'iconDescription', 'role', 'selected', 'style', 'tabContentClassName', 'triggerHref', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tabs, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class GlobalTheme(Component):
    """A GlobalTheme component.


Keyword arguments:

- children (optional):
    Provide the contents of your GlobalTheme.

- id (optional):
    Specify the DOM element ID of the top-level node.

- theme (optional):
    Specify the theme for your entire project."""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'GlobalTheme'
    @_explicitize_args
    def __init__(self, children=None, theme=Component.UNDEFINED, id=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'theme']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'theme']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(GlobalTheme, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Dropdown(Component):
    """A Dropdown component.
Dropdown component

Keyword arguments:

- id (string; required):
    Specify a custom `id`.

- ariaLabel (string; optional):
    'aria-label' of the ListBox component.

- disabled (boolean; optional):
    Disable the control.

- helperText (string | a list of or a singular dash component, string or number; optional):
    Provide helper text that is used alongside the control label for
    additional help.

- inline (boolean; optional):
    Specify whether you want the inline version of this control.

- invalid (boolean; optional):
    Specify if the currently selected value is invalid.

- invalidText (string; optional):
    Message which is displayed if the value is invalid.

- label (a list of or a singular dash component, string or number; required):
    Generic `label` that will be used as the textual representation of
    what this field is for.

- light (boolean; optional):
    `True` to use the light version.

- options (list of dicts; optional):
    List of items.

    `options` is a list of string | dict with keys:

    - label (string; optional)

    - value (boolean | number | string | dict | list; optional)s

- style (dict; optional):
    Style of the component.

- titleText (string | a list of or a singular dash component, string or number; optional):
    Provide the title text that will be read by a screen reader when
    visiting this control.

- value (boolean | number | string | dict | list; optional):
    In the case you want to control the dropdown selection entirely."""
    _children_props = ['label', 'titleText', 'helperText']
    _base_nodes = ['label', 'titleText', 'helperText', 'children']
    _namespace = 'dash_carbon_components'
    _type = 'Dropdown'
    @_explicitize_args
    def __init__(self, disabled=Component.UNDEFINED, options=Component.UNDEFINED, id=Component.REQUIRED, inline=Component.UNDEFINED, invalid=Component.UNDEFINED, invalidText=Component.UNDEFINED, label=Component.REQUIRED, translateWithId=Component.UNDEFINED, ariaLabel=Component.UNDEFINED, value=Component.UNDEFINED, light=Component.UNDEFINED, titleText=Component.UNDEFINED, helperText=Component.UNDEFINED, style=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'ariaLabel', 'disabled', 'helperText', 'inline', 'invalid', 'invalidText', 'label', 'light', 'options', 'style', 'titleText', 'value']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'ariaLabel', 'disabled', 'helperText', 'inline', 'invalid', 'invalidText', 'label', 'light', 'options', 'style', 'titleText', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['id', 'label']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Dropdown, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class UIShell(Component):
    """An UIShell component.
UIShell is a default layout with the header and a sidebar

Keyword arguments:

- id (string; optional):
    Element id.

- headerItems (list of dicts; optional):
    Items of the header.

    `headerItems` is a list of dicts with keys:

    - name (string; optional)

    - url (string; optional)

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- name (string; required):
    Platform Name.

- sidebarItems (list of dicts; optional):
    Items of the sidebar.

    `sidebarItems` is a list of dicts with keys:

    - name (string; optional)

    - url (string; optional)"""
    _children_props = []
    _base_nodes = ['children']
    _namespace = 'dash_carbon_components'
    _type = 'UIShell'
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, name=Component.REQUIRED, sidebarItems=Component.UNDEFINED, headerItems=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'headerItems', 'loading_state', 'name', 'sidebarItems']
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'headerItems', 'loading_state', 'name', 'sidebarItems']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['name']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(UIShell, self).__init__(**args)
